package com.glxp.udidl.admin.controller.tyapi;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageInfo;
import com.glxp.udidl.admin.annotation.AuthRuleAnnotation;
import com.glxp.udidl.admin.dto.udplat.UdplatManufactureModel;
import com.glxp.udidl.admin.entity.tyapi.TyCompanyDetailEntity;
import com.glxp.udidl.admin.entity.tyapi.TyCompanySearchEntity;
import com.glxp.udidl.admin.entity.tyapi.TySupplierEntity;
import com.glxp.udidl.admin.req.tyapi.TyBaseInfoRequest;
import com.glxp.udidl.admin.req.tyapi.TyImportSupRequest;
import com.glxp.udidl.admin.res.BaseResponse;
import com.glxp.udidl.admin.res.tyapi.TyBatchDlResponse;
import com.glxp.udidl.admin.res.tyapi.TyContactResponse;
import com.glxp.udidl.admin.service.tyapi.TyCompanyDetailService;
import com.glxp.udidl.admin.service.tyapi.TyCompanySearchService;
import com.glxp.udidl.admin.service.tyapi.TyContactInfoService;
import com.glxp.udidl.admin.service.tyapi.TySupplierService;
import com.glxp.udidl.admin.util.ResultVOUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@Api(tags = "天眼查API查询接口")
@RestController
public class TySearchController {

    @Resource
    TyCompanySearchService tyCompanySearchService;
    @Resource
    TySupplierService tySupplierService;
    @Resource
    TyCompanyDetailService tyCompanyDetailService;

    @ApiOperation(value = "天眼查企业信息查询(搜索查询)", response = TyCompanySearchEntity.class)
    @GetMapping("udidl/ty/company/findBycCeditCode")
    public BaseResponse findBycCeditCode(String creditCode) {
        if (StrUtil.isEmpty(creditCode)) {
            return ResultVOUtils.error(500, "统一社会信用代码不能为空！");
        }
        List<TyCompanySearchEntity> tyCompanySearchEntityList = tyCompanySearchService.list(new QueryWrapper<TyCompanySearchEntity>().eq("creditCode", creditCode));
        if (CollUtil.isEmpty(tyCompanySearchEntityList)) {
            return ResultVOUtils.error(500, "查无企业信息");
        } else {
            return ResultVOUtils.success(tyCompanySearchEntityList.get(0));
        }
    }

    @ApiOperation(value = "天眼查批量查询供应商列表接口")
    @PostMapping("/udidl/ty/company/batch/supplier")
    public BaseResponse supplierSearch(@RequestBody TyImportSupRequest tyImportSupRequest) {
        List<TySupplierEntity> tySupplierEntities = tySupplierService.filterList(tyImportSupRequest);
        PageInfo<TySupplierEntity> pageInfo = new PageInfo<>(tySupplierEntities);
        return ResultVOUtils.page(pageInfo);
    }


    @ApiOperation(value = "天眼查批量查询企业详细信息接口")
    @GetMapping("/udidl/ty/company/getBaseInfo")
    public BaseResponse getCompanyInfo(TyBaseInfoRequest tyBaseInfoRequest) {
        if (StrUtil.isEmpty(tyBaseInfoRequest.getName())
                && StrUtil.isEmpty(tyBaseInfoRequest.getCreditCode())
                && CollUtil.isNotEmpty(tyBaseInfoRequest.getSupCodes())
                && CollUtil.isNotEmpty(tyBaseInfoRequest.getSupNames())
        ) {
            return ResultVOUtils.error(500, "请输入企业名称或统一社会信用代码");
        }
        List<TyCompanyDetailEntity> tyCompanyDetailEntities = tyCompanyDetailService.filterList(tyBaseInfoRequest);
        PageInfo<TyCompanyDetailEntity> pageInfo = new PageInfo<>(tyCompanyDetailEntities);
        return ResultVOUtils.page(pageInfo);


    }

}
